Exception: Passkeyed::ChallengeMissing

Inherits:
Error
  • Object
show all
Defined in:
lib/passkeyed/errors.rb,
sig/passkeyed/errors.rbs

Overview

Raised when the server-issued challenge is absent from the session, which usually means the ceremony was started in a different session or the challenge was already consumed.

Direct Known Subclasses

ChallengeExpired